/*
  HC-SR04 One Common Pin - Testing

  Second HC-SR04 HC2 is optional comparative sensor

  TESLA INSTITUTE - www.facebook.com/teslainstitute
                    www.teslainstitute.blogspot.com
  Young English Engineer
  www.facebook.com/YoungEnglishEngineer

*/

const byte HC1_Pin = 5;  // one common pin HC-SR04 sensor HC1
const byte trigPin = 6;  // Trig pin HC-SR04 sensor HC2 (comparative)
const byte echoPin = 9;  // Echo pin HC-SR04 sensor HC2 (comparative)

long duration1;   // HC1 sound wave travel time in us
long duration2;   // HC2 sound wave travel time in us
float distance1;  // HC1 measured distance in cm
float distance2;  // HC2 measured distance in cm
int dt = 250;     // interval between measurement

void setup() {
  Serial.begin(9600);

  pinMode(trigPin, OUTPUT);
  pinMode(echoPin, INPUT);
}

void loop() {

  // Setup HC1_Pin as output
  pinMode(HC1_Pin, OUTPUT);
  // Clear trigPin for 2 us
  digitalWrite(HC1_Pin, LOW);
  delayMicroseconds(2);
  // Sets HC1 trigPin on HIGH state for 10 us
  digitalWrite(HC1_Pin, HIGH);
  delayMicroseconds(10);
  digitalWrite(HC1_Pin, LOW);
  // change HC1_Pin mode to input
  pinMode(HC1_Pin, INPUT);  // about 4.5 us 

  // HC-SR04 Ping transmission 8 pulses at 40 kHz - 200 us

  // Reads the echoPin, returns the sound
  // wave travel time in microseconds
  duration1 = pulseIn(HC1_Pin, HIGH);

  // 2.94117647058823*10^-5 = 29.41176 us/cm
  distance1 = (duration1 / 29.41176) / 2;

  delay(dt);

  // Comparative HC-SR04 HC2 sensor
  digitalWrite(trigPin, LOW);
  delayMicroseconds(2);
  // Sets HC2 trigPin on HIGH state for 10 us
  digitalWrite(trigPin, HIGH);
  delayMicroseconds(10);
  digitalWrite(trigPin, LOW);

  // Reads the echoPin, returns the sound
  // wave travel time in microseconds
  duration2 = pulseIn(echoPin, HIGH);
  distance2 = (duration2 / 29.41176) / 2;

  Serial.print(" Duration HC1: ");
  Serial.print(duration1);
  Serial.println(" us");
  Serial.print(" Duration HC2: ");
  Serial.print(duration2);
  Serial.println(" us");

  Serial.print(" Distance HC1: ");
  Serial.print(distance1, 1);
  Serial.println(" cm");
  Serial.print(" Distance HC2: ");
  Serial.print(distance2, 1);
  Serial.println(" cm");

  delay(dt);

}
